@@ -3,10 +3,10 @@ import Link from '../ui/Link';
 
 export default class RoleCard extends React.Component {
   render() {
-    let disabled = !this.props.availableNodesCount && !this.props.assignedNodesCount;
+    const disabled = !this.props.availableNodesCount && !this.props.assignedNodesCount;
 
     return (
-      <div className={`card-pf card-pf-accented role-card ${this.props.name}`}>
+      <div className={`card-pf card-pf-accented role-card ${this.props.identifier}`}>
         <h2 className="card-pf-title">
           {this.props.title}
         </h2>
@@ -16,10 +16,8 @@ export default class RoleCard extends React.Component {
               {this.props.assignedNodesCount}
             </span>
             <span className="card-pf-utilization-card-details-description">
-              <span className="card-pf-utilization-card-details-line-1">Nodes assigned</span>
-              <span className="card-pf-utilization-card-details-line-2">
-                of {this.props.availableNodesCount} available
-              </span>
+              <span className="card-pf-utilization-card-details-line-1">&nbsp;</span>
+              <span className="card-pf-utilization-card-details-line-2">Nodes assigned</span>
             </span>
           </p>
         </div>
@@ -27,7 +25,7 @@ export default class RoleCard extends React.Component {
           <p>
             <Link
               disabled={disabled}
-              to={`/deployment-plan/${this.props.name}/assignNodes`}
+              to={`/deployment-plan/${this.props.identifier}/assign-nodes`}
               className="card-pf-link-with-icon">
               <span className="pficon pficon-add-circle-o" />Assign Nodes
             </Link>
@@ -40,6 +38,7 @@ export default class RoleCard extends React.Component {
 RoleCard.propTypes = {
   assignedNodesCount: React.PropTypes.number.isRequired,
   availableNodesCount: React.PropTypes.number.isRequired,
+  identifier: React.PropTypes.string.isRequired,
   name: React.PropTypes.string.isRequired,
   title: React.PropTypes.string.isRequired
 };
